@@ -20,7 +20,7 @@ our @export_default = qw();
 	       );
 @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 @EXPORT = ();
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 # Use XS for fast xors (TODO: make this optional)
 require XSLoader;
@@ -390,9 +390,6 @@ sub _probability_distribution {
   }
 
   return [@P,1];
-
-  # old return:
-  # return ($f, $epsilon, @P, 1);
 }
 
 
@@ -426,8 +423,7 @@ sub fisher_yates_shuffle {
   my $i=scalar(@$array);
   while (--$i >= scalar(@$array) - $picks) {
     my $j=int($rng->rand($i + 1)); # range [0,$i]
-    #rint "fisher: rand j = $j\n";
-    next if $i==$j;
+    #next if $i==$j;	           # not worth checking, probably
     @$array[$i,$j]=@$array[$j,$i]
   }
 
@@ -499,8 +495,8 @@ sub auxiliary_mapping {
     #print "aux_mapping: shuffled list: " . (join " ", @$ab) . "\n";
 
     foreach my $aux (@$ab) {
-      $hashes[$aux]->{$msg}=1;
-      $hashes[$msg]->{$aux}=1;
+      $hashes[$aux]->{$msg}=undef;
+      $hashes[$msg]->{$aux}=undef;
     }
   }
 
@@ -531,7 +527,7 @@ sub blklist_to_msglist {
       if (exists($blocks{$entry})) {
 	delete $blocks{$entry};
       } else {
-	$blocks{$entry}=1;
+	$blocks{$entry}= undef;
       }
     } else {
       # aux block : push all message blocks it's composed of
@@ -556,7 +552,9 @@ sub toggle_key {
   if (exists($href->{$key})) {
     delete $href->{$key};
   } else {
-    $href->{$key}=1;
+    # apparently, using key => undef is more space-efficient than
+    # using key => 1 (similar changes made throughout this file)
+    $href->{$key}=undef;
   }
 }
 
@@ -647,7 +645,7 @@ sub checkblock_mapping {
   }
 
   # prevent generating this block again
-  $self->{unique}->{$key}=1;
+  $self->{unique}->{$key}=undef;
 
   #warn "Created unique, non-empty checkblock on try $tries\n" if $tries>1;
 
